// CkFtp2.h: interface for the CkFtp2 class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKFTP2_H
#define _CKFTP2_H

#pragma once


class CkByteData;
class CkCert;
class CkString;
#include "CkObject.h"

#pragma warning( disable : 4068 )
#pragma unmanaged

class CkFtpProgress;
/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */


// CLASS: CkFtp2
class CkFtp2  : public CkObject
{
    public:
	CkFtp2();
	virtual ~CkFtp2();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);

	bool UnlockComponent(const char *code);
	bool IsUnlocked(void) const;

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);

	bool get_IsConnected(void);

	// Return the number of files deleted.
	long DeleteMatching(const char *remotePattern);



	// Return the number of files retrieved.
	long MGetFiles(const char *remotePattern, const char *localDir);
	// Return the number of files uploaded.
	long MPutFiles(const char *pattern);

	bool GetFile(const char *remoteFilename,  const char *localFilename);
	bool PutFile(const char *localFilename,  const char *remoteFilename);

	bool PutFileFromBinaryData(const char *remoteFilename, CkByteData &binaryData);
	bool PutFileFromTextData(const char *remoteFilename, const char *textData);

	bool GetRemoteFileBinaryData(const char *remoteFilename, CkByteData &data);
	bool GetRemoteFileTextData(const char *remoteFilename, CkString &str);


	// Return the number of files retrieved.
	long MGetFiles2(const char *remotePattern, const char *localDir, CkFtpProgress &progress);
	// Return the number of files uploaded.
	long MPutFiles2(const char *pattern, CkFtpProgress &progress);

	bool GetFile2(const char *remoteFilename,  const char *localFilename, CkFtpProgress &progress);
	bool PutFile2(const char *localFilename,  const char *remoteFilename, CkFtpProgress &progress);

	bool PutFileFromBinaryData2(const char *remoteFilename, CkByteData &binaryData, CkFtpProgress &progress);
	bool PutFileFromTextData2(const char *remoteFilename, const char *textData, CkFtpProgress &progress);

	bool GetRemoteFileBinaryData2(const char *remoteFilename, CkByteData &data, CkFtpProgress &progress);
	bool GetRemoteFileTextData2(const char *remoteFilename, CkString &str, CkFtpProgress &progress);



	void get_Version(CkString &str);
	bool RenameRemoteFile(const char *existingFilename, const char *newFilename);
	bool DeleteRemoteFile(const char *filename);
	bool RemoveRemoteDir(const char *dir);
	bool CreateRemoteDir(const char *dir);

	bool Disconnect(void);
	bool Connect(void);

	bool GetCurrentRemoteDir(CkString &str);
	bool ChangeRemoteDir(const char *relativeDirPath);


	void get_ListPattern(CkString &strPattern);
	void put_ListPattern(const char *pattern);
	void get_Password(CkString &str);
	void put_Password(const char *newVal);
	void get_Username(CkString &str);
	void put_Username(const char *newVal);
	long get_Port(void);
	void put_Port(long newVal);
	void get_Hostname(CkString &str);
	void put_Hostname(const char *newVal);
	void get_SessionLog(CkString &str);
	bool get_Passive(void);
	void put_Passive(bool newVal);
	bool get_KeepSessionLog(void);
	void put_KeepSessionLog(bool newVal);

	long GetSize(long index);
	bool GetFilename(long index, CkString &str);
	bool GetIsDirectory(long index);
	bool GetCreateTime(long index, FILETIME &fTime);
	bool GetLastAccessTime(long index, FILETIME &fTime);
	bool GetLastModifiedTime(long index, FILETIME &fTime);

	long get_NumFilesAndDirs(void);
	void get_Proxy(CkString &str);
	void put_Proxy(const char *newVal);

	void ClearSessionLog(void);

	bool SetTypeBinary(void);
	bool SetTypeAscii(void);

	bool Site(const char *params);
	bool Syst(CkString &sOut);
	bool Stat(CkString &sOut);

	// Timeouts are in seconds
	long get_ReadTimeout(void);
	void put_ReadTimeout(long newVal);

	// Timeouts are in seconds
	long get_ConnectTimeout(void);
	void put_ConnectTimeout(long newVal);

	bool GetXmlDirListing(const char *pattern, CkString &strXmlListing);
	bool GetTextDirListing(const char *pattern, CkString &strRawListing);

	//bool CreatePlan(const char *localDir, CkString &str);
	//bool PutTree(const char *localDir);
	//bool PutPlan(const char *planUtf8, const char *planLogFilename);

	// END PUBLIC INTERFACE

    // For internal use only.
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkFtp2(const CkFtp2 &) { } 
	CkFtp2 &operator=(const CkFtp2 &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkFtp2(void *impl) : m_impl(impl) { }


};


#endif


